Site officiel de la Ville de Mons
Description: Actualités, événements, services en ligne, photos, vidéos... Tout sur Mons, capitale européenne de la culture en 2015!

Aller au contenu. | Aller à la navigation

- Plan du site
- Accessibilité
- Contact
- Se connecter

Chercher dans le site
Chercher par
Recherche avancée…

##### Thèmes

- Ma Ville
- Vivre à Mons
- Découvrir
- Culture
- Economie

##### Sections

Info # Recherche avancée Ce formulaire vous permet de rechercher du contenu sur le site en fonction de différents critères. N'oubliez pas que vous pouvez utiliser la recherche rapide à tout moment, ce qui est en général suffisant. Ce formulaire n'est là que si vous voulez effectuer une recherche plus spécifique. Texte à rechercher Pour une simple recherche plein texte, indiquez ici les mots à rechercher. Vous pouvez rechercher plusieurs mots en les combinant à l'aide de AND (ET) et OR (OU). Les mots indiqués seront recherchés à la fois dans le titre, la description et le contenu des éléments. Titre Recherche les éléments correspondant à ce titre. Mots-clés Recherche les éléments correspondants à l'un ou à tous les mots-clés sélectionnés. Plusieurs mots-clés peuvent être sélectionnés en gardant pressée la touche Ctrl (ou Pomme sur les Mac) lorsque vous cliquez sur les mots-clés. Un des mots-clés Tous les mots-clés Description Recherche les éléments correspondant à cette description. Vous pouvez indiquer plusieurs mots en les combinant avec les opérateurs AND (ET) et OR (OU). Éléments créés depuis Recherche les éléments ajoutés au site depuis votre dernière session, depuis la semaine dernière, etc. Type d'élément Recherche les éléments correspondant à l'un des types sélectionnés. Sélectionner tout/rien Association Bottin Associations Configuration Calendrier Document Événement Modèle FCKeditor Favori Fichier Dossier Formulaire Image Gros dossier Lien Actualité Newsletter Dossier contenant les abonnés Newsletter Reference Newsletter RichReference Newsletter Thème NewsletterTopic Sondage Section Abonné Carte Google Catégorie carte Google Type de contenu catégorie carte Google Conteneur de catégorie carte Google Marqueur carte Google Zone carte Google Chemins carte Google Collection Auteur Recherche les éléments créés par une personne en particulier. État de publication Vous pouvez affiner votre recherche en fonction de l'état de publication des éléments. Si vous voulez restreindre la recherche aux éléments qui sont dans certains états, sélectionnez ces derniers dans la liste. Sélectionner tout/rien Visible à l'extérieur Brouillon interne Publié en interne En attente de modération Privé Brouillon public Publié en création Désactivé Activé en attente de modération privé publié publié hors navigation publié dans la navigation